/// <reference types="bn.js" />
import { TransactionBuilder } from "@orca-so/common-sdk";
import { Address, BN } from "@project-serum/anchor";
import { PublicKey } from "@solana/web3.js";
import { WhirlpoolContext } from "../context";
import { AccountFetcher } from "../network/public";
import { Position, Whirlpool, WhirlpoolClient } from "../whirlpool-client";
import { FeeDiscountSwapQuote, SwapQuote } from "../quotes/public";
export declare class WhirlpoolClientImpl implements WhirlpoolClient {
    readonly ctx: WhirlpoolContext;
    constructor(ctx: WhirlpoolContext);
    getContext(): WhirlpoolContext;
    getFetcher(): AccountFetcher;
    getPool(poolAddress: Address, refresh?: boolean): Promise<Whirlpool>;
    getPools(poolAddresses: Address[], refresh?: boolean): Promise<Whirlpool[]>;
    getAllPositionsOf(owner: PublicKey, refresh?: boolean): Promise<Position[]>;
    getPosition(positionAddress: Address, refresh?: boolean): Promise<Position>;
    getPositions(positionAddresses: Address[], refresh?: boolean): Promise<Record<string, Position | null>>;
    createPool(whirlpoolsConfig: Address, tokenMintA: Address, tokenMintB: Address, tickSpacing: number, initialTick: number, funder: Address, refresh?: boolean): Promise<{
        poolKey: PublicKey;
        tx: TransactionBuilder;
    }>;
    collectFeesAndRewardsForPositions(positionAddresses: Address[], refresh?: boolean | undefined): Promise<TransactionBuilder[]>;
    collectProtocolFeesForPools(poolAddresses: Address[]): Promise<TransactionBuilder>;
    twoHopSwap(swapQuote1: SwapQuote, whirlpool1: Whirlpool, swapQuote2: SwapQuote, whirlpool2: Whirlpool, wRenecAta?: PublicKey): Promise<{
        tx: TransactionBuilder;
        createdWRenecAta: PublicKey | undefined;
    }>;
    twoHopSwapWithFeeDiscount(swapQuote1: FeeDiscountSwapQuote, whirlpool1: Whirlpool, swapQuote2: FeeDiscountSwapQuote, whirlpool2: Whirlpool, discountToken: PublicKey, wRenecAta?: PublicKey): Promise<{
        tx: TransactionBuilder;
        createdWRenecAta: PublicKey | undefined;
        estimatedBurnAmount: BN;
        estimatedDiscountAmount: BN;
    }>;
}
